@@ -36,25 +36,25 @@
 // and then checked back in. You cannot make changes to these sections without
 // corresponding changes to the buildmeister script
 #ifndef NV_BUILD_BRANCH
-    #define NV_BUILD_BRANCH             r581_07
+    #define NV_BUILD_BRANCH             VK580_65
 #endif
 #ifndef NV_PUBLIC_BRANCH
-    #define NV_PUBLIC_BRANCH             r581_07
+    #define NV_PUBLIC_BRANCH             VK580_65
 #endif
 
 #if defined(NV_LINUX) || defined(NV_BSD) || defined(NV_SUNOS)
-#define NV_BUILD_BRANCH_VERSION         "rel/gpu_drv/r580/r581_07-226"
-#define NV_BUILD_CHANGELIST_NUM         (36455674)
+#define NV_BUILD_BRANCH_VERSION         "rel/gpu_drv/r580/VK580_65-178"
+#define NV_BUILD_CHANGELIST_NUM         (36629274)
 #define NV_BUILD_TYPE                   "Official"
-#define NV_BUILD_NAME                   "rel/gpu_drv/r580/r581_07-226"
-#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36455674)
+#define NV_BUILD_NAME                   "rel/gpu_drv/r580/VK580_65-178"
+#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36629274)
 
 #else     /* Windows builds */
-#define NV_BUILD_BRANCH_VERSION         "r581_07-4"
-#define NV_BUILD_CHANGELIST_NUM         (36452923)
+#define NV_BUILD_BRANCH_VERSION         "VK580_65-5"
+#define NV_BUILD_CHANGELIST_NUM         (36629274)
 #define NV_BUILD_TYPE                   "Official"
-#define NV_BUILD_NAME                   "581.18"
-#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36452923)
+#define NV_BUILD_NAME                   "581.51"
+#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36629274)
 #define NV_BUILD_BRANCH_BASE_VERSION    R580
 #endif
 // End buildmeister python edited section
